@@ -1,13 +1,13 @@
-# Copyrights 2008-2014 by [Mark Overmeer].
+# Copyrights 2008-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package XML::Compile::Cache;
 use vars '$VERSION';
-$VERSION = '1.03';
+$VERSION = '1.05';
 
 use base 'XML::Compile::Schema';
 
@@ -117,7 +117,6 @@ sub addPrefixes(@)
       : ref $first eq 'ARRAY' ? @$first
       : ref $first eq 'HASH'  ? %$first
       : error __x"prefixes() expects list of PAIRS, an ARRAY or a HASH";
-# warn "new prefixes: @pairs\n";
 
     my $a    = $self->{XCC_prefixes} ||= {};
     while(@pairs)
@@ -424,6 +423,9 @@ sub mergeCompileOptions($$$)
                 push @{$x{$self->findName($t)}},  @a;
             }
         }
+        elsif($opt eq 'ignore_unused_tags')
+        {   $opts{$opt} = defined $opts{$opt} ? qr/$opts{$opt}|$val/ : $val;
+        }
         else
         {   $opts{$opt} = $val;
         }
@@ -527,7 +529,8 @@ sub findName($)
     defined $name
         or panic "findName called without name";
 
-    return $name if $name =~ m/^\{/;
+    return $name
+        if substr($name, 0, 1) eq '{';
 
     my ($prefix,$local) = $name =~ m/^([\w-]*)\:(\S*)$/ ? ($1,$2) : ('',$name);
     my $def = $self->{XCC_prefixes}{$prefix};
@@ -582,9 +585,6 @@ sub printIndex(@)
 sub _convertAnyTyped(@)
 {   my ($self, $type, $nodes, $path, $read) = @_;
 
-{no warnings;
-defined $read or warn join ';', caller(0);
-}
     my $key     = $read->keyRewrite($type);
     my $reader  = try { $self->reader($type) };
     if($@)
@@ -605,13 +605,13 @@ sub _convertAnySloppy(@)
     my $reader  = try { $self->reader($type) };
     if($@)
     {   # unknown type or untyped...
-        my @convert = map {XMLin $_} @$nodes;
+        my @convert = map XMLin($_), @$nodes;
         return ($key => @convert==1 ? $convert[0] : \@convert);
     }
     else
     {   trace "auto-convert known 'any' $type";
         my @nodes   = ref $nodes eq 'ARRAY' ? @$nodes : $nodes;
-        my @convert = map {$reader->($_)} @nodes;
+        my @convert = map $reader->($_), @nodes;
 
         ($key => @convert==1 ? $convert[0] : \@convert);
     }
